@@ -29,9 +29,19 @@ use base qw(Text::CSV::Track);
 
 use FindBin;
 
-use Text::CSV;
+use Text::CSV_XS;
 use Carp::Clan;
 
+=head1 METHODS
+
+=over 4
+
+=item value_of()
+
+Overridden function from L<Text::CSV::Tack> that stores value only if it is
+greater then the one before. 
+
+=cut
 
 sub value_of {
 	my $self          = shift;
@@ -62,5 +72,9 @@ sub value_of {
 	}
 }
 
+=back
+
+=cut
+
 1;
 
